==> transactions-3.6.4-sources.jar: com/atomikos/icatch/imp/thread/TrivialSystemExecutor.java <==

              
/*
 * Copyright 2000-2008, Atomikos (http://www.atomikos.com) 
 *
 * This code ("Atomikos TransactionsEssentials"), by itself, 
 * is being distributed under the 
 * Apache License, Version 2.0 ("License"), a copy of which may be found at 
 * http://www.atomikos.com/licenses/apache-license-2.0.txt . 
 * You may not use this file except in compliance with the License. 
 *             
 * While the License grants certain patent license rights, 
 * those patent license rights only extend to the use of 
 * Atomikos TransactionsEssentials by itself. 
 *             
 * This code (Atomikos TransactionsEssentials) contains certain interfaces 
 * in package (namespace) com.atomikos.icatch
 * (including com.atomikos.icatch.Participant) which, if implemented, may
 * infringe one or more patents held by Atomikos.  
 * It should be appreciated that you may NOT implement such interfaces; 
 * licensing to implement these interfaces must be obtained separately from Atomikos.
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  
 */
 
package com.atomikos.icatch.imp.thread;

import com.atomikos.icatch.system.Configuration;

/**
 * This is an executor which creates a new thread for each
 * invocation. It uses the SystemThreadFactorySPI for the task.
 */
public class TrivialSystemExecutor implements InternalSystemExecutor
{
	
	public TrivialSystemExecutor()
	{
	}
	
	public void execute(Runnable targ)
	{
		Configuration.logDebug("(T) executing task: " + targ);
		Thread newThread = ThreadFactory.getInstance().newThread(targ);
		newThread.start();
	}
	
	public void shutdown()
	{
	}

}

==> transactions-3.7.0-sources.jar: com/atomikos/icatch/imp/thread/TrivialSystemExecutor.java <==
/**
 * Copyright (C) 2000-2010 Atomikos <info@atomikos.com>
 *
 * This code ("Atomikos TransactionsEssentials"), by itself,
 * is being distributed under the
 * Apache License, Version 2.0 ("License"), a copy of which may be found at
 * http://www.atomikos.com/licenses/apache-license-2.0.txt .
 * You may not use this file except in compliance with the License.
 *
 * While the License grants certain patent license rights,
 * those patent license rights only extend to the use of
 * Atomikos TransactionsEssentials by itself.
 *
 * This code (Atomikos TransactionsEssentials) contains certain interfaces
 * in package (namespace) com.atomikos.icatch
 * (including com.atomikos.icatch.Participant) which, if implemented, may
 * infringe one or more patents held by Atomikos.
 * It should be appreciated that you may NOT implement such interfaces;
 * licensing to implement these interfaces must be obtained separately from Atomikos.
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 */

package com.atomikos.icatch.imp.thread;

import com.atomikos.icatch.system.Configuration;

/**
 * This is an executor which creates a new thread for each
 * invocation. It uses the SystemThreadFactorySPI for the task.
 */
public class TrivialSystemExecutor implements InternalSystemExecutor
{
	
	public TrivialSystemExecutor()
	{
	}
	
	public void execute(Runnable targ)
	{
		if ( Configuration.isDebugLoggingEnabled() ) Configuration.logDebug("(T) executing task: " + targ);
		Thread newThread = ThreadFactory.getInstance().newThread(targ);
		newThread.start();
	}
	
	public void shutdown()
	{
	}

}
